@@ -2,5 +2,5 @@ from .json import JsonYhteys
 from .rajapinta import Rajapinta
 from .rest import RestYhteys
 from .sanoma import RestKentta, RestValintakentta, RestSanoma
-from .tyokalut import ei_syotetty, mittaa
+from .tyokalut import ei_syotetty, mittaa, periyta, Rutiini
 from .yhteys import AsynkroninenYhteys
